@@ -1,5 +1,3 @@
-( cd opt/kde/share/doc/HTML/ja/kdesu ; rm -rf common )
-( cd opt/kde/share/doc/HTML/ja/kdesu ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
 ( cd opt/kde/share/doc/HTML/ja/khelpcenter ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ja/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
 ( cd opt/kde/share/doc/HTML/ja/common ; rm -rf fdl-license )
@@ -38,6 +36,8 @@
 ( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/grad.png grad.png )
 ( cd opt/kde/share/doc/HTML/ja/common ; rm -rf kde-web.css )
 ( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
+( cd opt/kde/share/doc/HTML/ja/common ; rm -rf kde_logo_bg.png )
+( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
 ( cd opt/kde/share/doc/HTML/ja/common ; rm -rf lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/ja/common ; rm -rf doxygen.css )
@@ -52,12 +52,16 @@
 ( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/ja/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/ja/common ; rm -rf appheader.html )
+( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/ja/common ; rm -rf doctop1.png )
 ( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
 ( cd opt/kde/share/doc/HTML/ja/common ; rm -rf doctop2.png )
 ( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
 ( cd opt/kde/share/doc/HTML/ja/common ; rm -rf shadow.png )
 ( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/shadow.png shadow.png )
+( cd opt/kde/share/doc/HTML/ja/common ; rm -rf kde_logo.png )
+( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/ja/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
 ( cd opt/kde/share/doc/HTML/ja/common ; rm -rf fdl-license.html )
@@ -166,8 +170,6 @@
 ( cd opt/kde/share/doc/HTML/ja/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
 ( cd opt/kde/share/doc/HTML/ja/kcontrol/kthememgr ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ja/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
-( cd opt/kde/share/doc/HTML/ja/kspell ; rm -rf common )
-( cd opt/kde/share/doc/HTML/ja/kspell ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
 ( cd opt/kde/share/doc/HTML/ja/kinfocenter/dma ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ja/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
 ( cd opt/kde/share/doc/HTML/ja/kinfocenter/pci ; rm -rf common )
